use strict;
use warnings;
package ACME::Experiment;

use ACME::Experiment::A;
use ACME::Experiment::B;

sub new {
    my $class;
    return bless {}, $class;
}

=head1 NAME

ACME::Experiment - experimenting with PAUSE permissions

=head1 DESCRIPTION

This is not the module you're looking for.
I'm testing various things related to PAUSE permissions.

=cut

1;
